#-----------------------------------------------------------------------------
# magnet symmetry
# Jan. 8, 2003, by Ockham
# Modified by Les Bentley, 11/August/2007.
# Modifications cause xTran, yRotate, and zRotate, 
# to be mirrored for ALL elements of the magnet.
#-----------------------------------------------------------------------------
# Select the part that has the magnet.
# Activate the script.  If the part is 'central' we duplicate
# the magnet on the same part with opposite xTran, yRotate, and zRotate.
# If the part is left or right, we dup the magnet on the oppositely
# handed part, with opposite xTran, yRotate, and zRotate.

#-----------------------------------------------------------------------------

import poser

#-----------------------------------------------------------------------------

scene = poser.Scene()
scene.SetFrame(0)

#-----------------------------------------------------------------------------
MagName = "Mag"
OrigMag = 0

# See if the currently selected object has a magnet.
TrySelected = scene.CurrentActor()
TryFig = TrySelected.ItsFigure()
# The Base and Zone are both childs of the Actor.
# The Mag is a child of the Base.
# So we look first for Base and Zone, then get the Mag
# as the only child of Base.

for TryPart in TrySelected.Children():
    TryName = TryPart.Name()
    if TryPart.IsBase(): # this is a base
       OrigBase = TryPart
    if TryPart.IsZone(): # this is a zone
       OrigZone = TryPart

if not OrigBase:
   raise "Selected part has no magnet."

# the Magnet itself is the Base's only child:
for TryChild in OrigBase.Children():
    TryName = TryChild.Name()
    if TryName[0:len(MagName)] == MagName: # probably redundant
       OrigMag = TryChild

# Make a new magnet.
# Here's where we switch sides if needed.
SelName = TrySelected.InternalName()
if   SelName[0] == "l":
   NewName = "r" + SelName[1:]
elif SelName[0] == "r":
   NewName = "l" + SelName[1:]
else:
   NewName = SelName

try:
    NewSelected = TryFig.ActorByInternalName(NewName)
except:
    raise "No symmetrical part"
# Select the new part.
scene.SelectActor(NewSelected)

# Make a magnet on the new part.
try:
    scene.CreateMagnet()
except:
    raise "Can't make new magnet"

# Run similar loop to find the new mag for sure.
for TryPart in NewSelected.Children():
    TryName = TryPart.Name()
    if TryPart.IsBase(): # this is a base
       NewBase = TryPart
    if TryPart.IsZone(): # this is a zone
       NewZone = TryPart

if not NewBase:
   raise "New part has no magnet."

# the Magnet itself is the Base's only child:
for TryChild in NewBase.Children():
    TryName = TryChild.Name()
    if TryName[0:len(MagName)] == MagName: # probably redundant
       NewMag = TryChild

# Put all the parms of the original mag onto the new. I think
for OneParm in OrigMag.Parameters():
    ParmName = OneParm.Name()
    Val = OneParm.Value()
    NewParm = NewMag.Parameter(ParmName)
    if ParmName == "xTran":  # reverse the xtran
       NewParm.SetValue(-Val)
    elif ParmName == "yRotate":  # reverse the yRotate
       NewParm.SetValue(-Val)
    elif ParmName == "zRotate":  # reverse the zRotate
       NewParm.SetValue(-Val)
    else:
       NewParm.SetValue(Val) # copy others

# Put all the parms of the original base onto the new:
for OneParm in OrigBase.Parameters():
    ParmName = OneParm.Name()
    Val = OneParm.Value()
    NewParm = NewBase.Parameter(ParmName)
    if ParmName == "xTran":  # reverse the xtran
       NewParm.SetValue(-Val)
    elif ParmName == "yRotate":  # reverse the yRotate
       NewParm.SetValue(-Val)
    elif ParmName == "zRotate":  # reverse the zRotate
       NewParm.SetValue(-Val)
    else:
       NewParm.SetValue(Val) # copy others

# Put all the parms of the original zone onto the new:
for OneParm in OrigZone.Parameters():
    ParmName = OneParm.Name()
    Val = OneParm.Value()
    NewParm = NewZone.Parameter(ParmName)
    if ParmName == "xTran":  # reverse the xtran
       NewParm.SetValue(-Val)
    elif ParmName == "yRotate":  # reverse the yRotate
       NewParm.SetValue(-Val)
    elif ParmName == "zRotate":  # reverse the zRotate
       NewParm.SetValue(-Val)
    else:
       NewParm.SetValue(Val) # copy others

# That's all, folks!
#-----------------------------------------------------------------------------
 

